@@ -68,7 +68,8 @@ usage_and_bye (void)
 	    "     --noautofun       Don't Automatically turn on Fun Mode\n"
             "     --revmousewheel   Reverse the mousewheel\n"
             "     --swapmousebuttons Swap the mousebuttons\n"
-            "     --altmousebuttons Use alternate mousebuttons scheme\n\n"
+            "     --altmousebuttons Use alternate mousebuttons scheme\n"
+            "     --justswitch      Just switch desktops and acquire without graphics\n\n"
         );
     exit (1);
 }
@@ -103,6 +104,7 @@ int main(int argc, char **argv)
 	{"revmousewheel", 0, 0, 0},
 	{"swapmousebuttons", 0, 0, 0},
 	{"altmousebuttons", 0, 0, 0},
+	{"justswitch", 0, 0, 0},
         {0, 0, 0, 0}
     };
 
@@ -223,6 +225,9 @@ int main(int argc, char **argv)
 	    case 21: // 'altmousebuttons'
 		msgmgr.msg.alt_mousebuttons = 1;
                 break;
+            case 22: // 'justswitch'
+                msgmgr.msg.mtype = MTYPE_JUSTSWITCH;
+                break;
             }
             break;
         case 'v':
