@@ -206,8 +206,6 @@ static void begin_exit (void);
 static desktop_coords_t wait_for_activation(void);
 static void idle_func(void);
 static int main_loop(void);
-static void entry_move_start_hook (Event *e);
-static void exit_move_start_hook (Event *e);
 static void gl_init (void);
 static void initialize_3ddesktop (void);
 static void load_digits(void);
@@ -222,10 +220,12 @@ goto_face_complete (Event *e)
     goto_on_flag = 0;
 
     //msgout (DEBUG, "-=-=-=-=- goto_face_complete\n");
-    if (!cfg->options->disable_exit_after_goto)
+
+    if (!cfg->options->disable_exit_after_goto) {
         begin_exit();
-    else 
+    } else {
         cfg->options->disable_exit_after_goto = false;  // dont want this option "sticky"
+    }
 
 }
 
@@ -244,10 +244,11 @@ static void
 goto_face_start_exit (Event *e)
 {
     //msgout (DEBUG, "-=-=-=-=- goto_face_start_exit\n");
-    if (!cfg->options->disable_exit_after_goto)
+    if (!cfg->options->disable_exit_after_goto) {
         begin_exit();
-    else 
+    } else {
         cfg->options->disable_exit_after_goto = false;  // dont want this option "sticky"
+    }
 
 }
 
@@ -286,6 +287,7 @@ exit_move_start_hook (Event *e)
 }
 
 
+
 static void 
 setup_goto_face(desktop_coords_t  goto_coords, 
                 desktop_coords_t  current_coord, 
@@ -1394,6 +1396,7 @@ begin_exit (void)
         // face is complete
         msgout (DEBUG, "cant exit in goto....\n");
         SET_STATE(STATE_GOTO);
+        em.remove_event (GOTO_FACE_COMPLETE, goto_face_complete2);
         em.add_event (GOTO_FACE_COMPLETE, goto_face_complete);
         return;
     }
@@ -1562,7 +1565,72 @@ wait_for_activation(void)
             continue;  // don't activate
 
             break;
+        case MTYPE_JUSTSWITCH:
+            
+            goto_coords.column = msgmgr.msg.goto_column;
+            goto_coords.row = msgmgr.msg.goto_row;
+            
+            if (goto_coords.column == NO_GOTO &&
+                goto_coords.row    == NO_GOTO)
+                continue;  // do nothing
 
+            // assign as current col/row if no_goto
+            if (goto_coords.column == NO_GOTO)
+                goto_coords.column = current_col + 1;
+
+            if (goto_coords.row == NO_GOTO)
+                goto_coords.row = current_row + 1;
+
+            // if we are asked to goto the current row and column then
+            // do nothing
+            if (goto_coords.column == (current_col + 1)
+                && goto_coords.row == (current_row + 1))
+                continue;
+
+            // check bounds on goto column
+            if ( goto_coords.column < 1
+                 || goto_coords.column > col_count )
+            {
+                msgout (DEBUG, "Ignoring out of bounds goto column of %d\n", goto_coords.column);
+                continue;
+            }
+
+
+            // check bounds on goto row
+            if ( goto_coords.row < 1
+                 || goto_coords.row > row_count )
+            {
+                msgout (DEBUG, "Ignoring out of bounds goto row of %d\n", goto_coords.row);
+                continue;
+            }
+
+            // capture the current desktop
+            if (GLWin.grab_screenshot_data() < 0) {
+                msgout (ERROR, "couldn't grab screen image\n");
+                end_program(-1);
+            }
+                    
+            face_set->load_texture_data(current_col + (current_row * col_count), 
+                                        cfg->texture_size,
+                                        GLWin.get_screenshot_data_ptr() );
+            
+            // now go to the specified desktop
+            vdesks.set_vdesktop (goto_coords.column-1, goto_coords.row-1);
+
+            // now capture this desktop so we have an updated image
+            if (GLWin.grab_screenshot_data() < 0) {
+                msgout (ERROR, "couldn't grab screen image\n");
+                end_program(-1);
+            }
+                    
+            face_set->load_texture_data((goto_coords.column-1) + ((goto_coords.row-1) * col_count), 
+                                        cfg->texture_size,
+                                        GLWin.get_screenshot_data_ptr() );
+            
+            // we are done and do not activate.
+            continue;
+
+            break;
         case MTYPE_ACTIVATE:
 
             if (strlen(msgmgr.msg.view)) {
