@@ -1837,9 +1837,43 @@ float FlipArrangement::goto_face (desktop_coords_t dest)
 
     int newface = dest.column + (dest.row * n_columns);
 
+    int current = current_col + (current_row * n_columns);
+
+    int number = n_columns * n_rows;
+
+    int direction = 1;
+
+    // figure out which way to turn to get to the face.
+    // This code was taken from carousel goto_face and can
+    // be improved/simplified no doubt.  This still does not
+    // work if we are mid-goto.
+    if (newface > current) {
+        if ( (newface - current) <
+             ((current + number) - newface) )
+        { 
+            // left
+            direction = -1;
+        } else {
+            // right
+            direction = 1;
+        }
+    } else {
+        // newface < current
+
+        if ( (current - newface) >
+             ((newface + number) - current) )
+        {
+            // left
+            direction = -1;
+        } else {
+            // right
+            direction = 1;
+        }
+    }
+
     if (goto_face_mv.at_destination())
         goto_face_mv.init (&goto_face_val, goto_face_val, 
-                           goto_face_val + per_face_change,
+                           goto_face_val + per_face_change * direction,
                            cfg->options->face_change_steps, move_type);
     else
         goto_face_mv.init (&goto_face_val, goto_face_val, 
