@@ -463,7 +463,14 @@ public:
             __disable_keys_in_goto = get_boolean (value);
 
         } else if (strcmp(option, "autoacquire") == 0) {
-            __autoacquire = atoi (value);
+            if (!strcmp(value, "off") ||
+                !strcmp(value, "no") ||
+                !strcmp(value, "false")) 
+            {
+                __autoacquire = 0;
+            } else {
+                __autoacquire = atoi (value);
+            }
             
         } else if (strcmp(option, "dontexit") == 0) {
             disable_exit_after_goto = get_boolean (value);
