@@ -115,6 +115,8 @@ int load_image(char *filename,
 	msgout(ERROR,"Error reading width from %s.\n", filename);
 	return 0;
     }
+    *sizex = bswap_32(*sizex);
+
     //msgout(DEBUG,"Width of %s: %u\n", filename, *sizex);
     
     // read the height 
@@ -122,6 +124,8 @@ int load_image(char *filename,
 	msgout(ERROR,"Error reading height from %s.\n", filename);
 	return 0;
     }
+    *sizey = bswap_32(*sizey);
+
     //msgout(DEBUG,"Height of %s: %u\n", filename, *sizey);
     
     // read the planes
@@ -129,6 +133,8 @@ int load_image(char *filename,
 	msgout(ERROR,"Error reading planes from %s.\n", filename);
 	return 0;
     }
+    planes = bswap_16(planes);
+
     if (planes != 1) {
 	msgout(ERROR,"Planes from %s is not 1: %u\n", filename, planes);
 	return 0;
@@ -139,6 +145,7 @@ int load_image(char *filename,
 	msgout(ERROR,"Error reading bpp from %s.\n", filename);
 	return 0;
     }
+    bpp = bswap_16(bpp);
 
     //msgout(DEBUG,"BPP from %s is %u\n", filename, bpp);
 
