@@ -129,7 +129,7 @@ int GLWindow::open_display()
     imlib_context_set_anti_alias(1);
     imlib_context_set_blend(0);
 
-    img = imlib_create_image(screen_width, screen_height);
+ //   img = imlib_create_image(screen_width, screen_height);
 
     XSetErrorHandler(X_errors_handler);
 
@@ -162,21 +162,14 @@ int GLWindow::create_GL_window(char *title, Bool fs)
 {
     Colormap cmap;
     int dpyWidth, dpyHeight;
-    int i;
     int glxMajorVersion, glxMinorVersion;
     int vidModeMajorVersion, vidModeMinorVersion;
-    XF86VidModeModeInfo **modes;
-    int modeNum;
-    int bestMode;
     Atom wmDelete;
     Window winDummy;
     unsigned int borderDummy;
     
     static int first_time = 1;
 
-    /* set best mode to current */
-    bestMode = 0;
-
     fullscreen = fs;
 
     if (fullscreen) {
@@ -195,17 +188,6 @@ int GLWindow::create_GL_window(char *title, Bool fs)
     msgout(DEBUG, "XF86VidModeExtension-Version %d.%d\n", vidModeMajorVersion,
            vidModeMinorVersion);
 
-    XF86VidModeGetAllModeLines(display, screen, &modeNum, &modes);
-    /* save desktop-resolution before switching modes */
-    deskMode = *modes[0];
-    /* look for mode with requested resolution */
-    for (i = 0; i < modeNum; i++)
-    {
-        if ((modes[i]->hdisplay == width) && (modes[i]->vdisplay == height))
-        {
-            bestMode = i;
-        }
-    }
 
     /* get an appropriate visual */
     vi = glXChooseVisual(display, screen, attrListDbl);
@@ -220,7 +202,7 @@ int GLWindow::create_GL_window(char *title, Bool fs)
     }
     glXQueryVersion(display, &glxMajorVersion, &glxMinorVersion);
     
-        msgout(DEBUG, "glX-Version %d.%d\n", glxMajorVersion, glxMinorVersion);
+    msgout(DEBUG, "glX-Version %d.%d\n", glxMajorVersion, glxMinorVersion);
     
 
 
@@ -242,17 +224,13 @@ int GLWindow::create_GL_window(char *title, Bool fs)
 
     if (fullscreen)
     {
-        fullscreenMode = *modes[bestMode];
-
-        XF86VidModeSwitchToMode(display, screen, modes[bestMode]);
         XF86VidModeSetViewPort(display, screen, 0, 0);
-        dpyWidth = modes[bestMode]->hdisplay;
-        dpyHeight = modes[bestMode]->vdisplay;
+
+        dpyWidth = screen_width;
+        dpyHeight = screen_height;
 
         msgout(DEBUG, "Resolution %dx%d\n", dpyWidth, dpyHeight);
 
-        XFree(modes);
-    
         /* create a fullscreen window */
         attr.override_redirect = True;
         attr.event_mask = ExposureMask | KeyPressMask | ButtonPressMask |
@@ -336,10 +314,12 @@ int GLWindow::create_GL_window(char *title, Bool fs)
     if (glXIsDirect(display, ctx)) 
         msgout(DEBUG, "Congrats, you have Direct Rendering!\n");
     else {
-        msgout (ERROR, "glXIsDirect failed, no Direct Rendering possible!\n");
-        msgout (ERROR, "Please configure hardware acceleration.  Exiting.\n");
-        fprintf (stderr, "3ddeskd: glXIsDirect failed, no Direct Rendering possible!\n");
-        fprintf (stderr, "3ddeskd: Please configure hardware acceleration.  Exiting.\n");
+        msgout (ERROR, 
+                "glXIsDirect failed, no Direct Rendering possible!\n"
+                "Please configure hardware acceleration.  Exiting.\n");
+        fprintf (stderr, 
+                 "3ddeskd: glXIsDirect failed, no Direct Rendering possible!\n"
+                 "3ddeskd: Please configure hardware acceleration.  Exiting.\n");
         end_program(-1);
     }
 
@@ -376,10 +356,8 @@ int GLWindow::kill_GL_window ()
 
     XSync(display, 0);
 
-    /* switch back to original desktop resolution if we were in fs */
     if (fullscreen)
     {
-        XF86VidModeSwitchToMode(display, screen, &deskMode);
         XF86VidModeSetViewPort(display, screen, 0, 0);
     }
     return 0;
@@ -388,7 +366,6 @@ int GLWindow::kill_GL_window ()
 int GLWindow::unhide_GL_window()
 {
     if (fullscreen) {
-        XF86VidModeSwitchToMode(display, screen, &fullscreenMode);
         XF86VidModeSetViewPort(display, screen, 0, 0);
     }
 
@@ -431,7 +408,6 @@ int GLWindow::hide_GL_window()
 
     if (fullscreen)
     {
-        XF86VidModeSwitchToMode(display, screen, &deskMode);
         XF86VidModeSetViewPort(display, screen, 0, 0);
     }
     return 0;
@@ -480,11 +456,12 @@ int GLWindow::grab_screenshot_data_portion(int x1, int y1, int x2, int y2)
             msgout (ERROR, "out of memory\n");
             end_program(-1);
         }
-
-        imgfinal = imlib_create_image(cfg->texture_size, cfg->texture_size);
-
     }
 
+
+    Imlib_Image img = imlib_create_image(screen_width, screen_height);
+    Imlib_Image imgfinal = imlib_create_image(cfg->texture_size, cfg->texture_size);
+
     /* set the display , visual, colormap and drawable we are using */
     imlib_context_set_image(img);
     imlib_copy_drawable_to_image((Pixmap)0, //Pixmap mask, 
@@ -533,7 +510,9 @@ int GLWindow::grab_screenshot_data_portion(int x1, int y1, int x2, int y2)
 
         }
     }
-
+    imlib_free_image();
+    imlib_context_set_image(img);
+    imlib_free_image();
     return 0;
 }
 
@@ -547,26 +526,16 @@ int GLWindow::grab_screenshot_data()
             msgout (ERROR, "out of memory\n");
             end_program(-1);
         }
-
-        imgfinal = imlib_create_image(cfg->texture_size, cfg->texture_size);
     }
 
-    /* set the display , visual, colormap and drawable we are using */
+    Imlib_Image img = imlib_create_image_from_drawable((Pixmap)0,0,0,screen_width,screen_height,1);
+   
     imlib_context_set_image(img);
-    imlib_copy_drawable_to_image((Pixmap)0, //Pixmap mask, 
-                                 0, 0, //int x, int y, 
-                                 screen_width, //int width, int height,
-                                 screen_height,
-                                 0, 0, //int destination_x, int destination_y,
-                                 1 ); //char need_to_grab_x);
-
-    imlib_context_set_image(imgfinal);
-    imlib_image_clear();
-
-    imlib_blend_image_onto_image(img, 0, 
-                                 0, 0, screen_width, screen_height, 
-                                 0, 0, cfg->texture_size, cfg->texture_size);
-
+    Imlib_Image imgfinal = imlib_create_cropped_scaled_image(0, 0, 
+                                      screen_width, screen_height,
+                                                cfg->texture_size,
+                                                cfg->texture_size);  
+    imlib_context_set_image(imgfinal);	   
     unsigned int *tmp = imlib_image_get_data();
 
     int w = imlib_image_get_width();
@@ -593,7 +562,9 @@ int GLWindow::grab_screenshot_data()
 
         }
     }
-
+    imlib_free_image();			// saves ~ 10MB of res. Mem @1024x1024 texture_size
+    imlib_context_set_image(img);
+    imlib_free_image();
     return 0;
 }
 
