@@ -76,6 +76,7 @@ int VDesktops::init(Config *_cfg)
     return 0;
 }
 
+
 void VDesktops::get_vdesktop_info (int *column, int *row, 
                                    int *n_columns, int *n_rows)
 {
@@ -90,29 +91,21 @@ void VDesktops::get_vdesktop_info (int *column, int *row,
 #endif // HAVE_KDE
 
     if (cfg->sawfish_only) {
-        //msgout(DEBUG, "vdesktops: sawfish only\n");
+        msgout(DEBUG, "vdesktops: sawfish only\n");
         c = sawfish_get_current_workspace();
         nc = sawfish_get_workspace_count();
         nr = 1;
 
-    } else if (cfg->use_workspaces) {
-        //msgout(DEBUG, "vdesktops: workspaces only\n");
-        struct gnome_workspace_info wi;
-        gnome_get_workspace_info (&wi);
-        c = wi.workspace;
-        nc = wi.workspace_count;
-        nr = 1;
-
     } else if (cfg->use_ewmh) {
-        //msgout (DEBUG, "vdesktops: EWMH\n");
+        msgout (DEBUG, "vdesktops: EWMH\n");
         struct gnome_workspace_info wi;
         ewmh_get_desktop_info (&wi);
         c = wi.workspace;
         nc = wi.workspace_count;
         nr = 1;
 
-    } else {
-        //msgout(DEBUG, "vdesktops: areas\n");
+    } else if (cfg->use_viewareas) {
+        msgout(DEBUG, "vdesktops: areas\n");
         struct gnome_area_info ai;
         gnome_get_area_info(&ai);
         c = ai.harea;
@@ -120,15 +113,59 @@ void VDesktops::get_vdesktop_info (int *column, int *row,
         nc = ai.harea_count;
         nr = ai.varea_count;
 
-        if (nc == 1 && nr == 1) {
-            // columns and rows is from workspaces
+        if (nc == 1 && nr == 1 && cfg->use_workspaces) {
+            // try workspaces
             struct gnome_workspace_info wi;
             gnome_get_workspace_info (&wi);
             c = wi.workspace;
             nc = wi.workspace_count;
             nr = 1;
-            if (nc > 1) cfg->use_workspaces = 1;
-        }
+            if (nc <= 1) 
+                msgout (ERROR, "Could not find more then one virtual desktop!\n");
+        } else 
+            cfg->use_workspaces = 0;
+        
+
+    } else if (cfg->use_workspaces) {
+        msgout(DEBUG, "vdesktops: workspaces only\n");
+        struct gnome_workspace_info wi;
+        gnome_get_workspace_info (&wi);
+        c = wi.workspace;
+        nc = wi.workspace_count;
+        nr = 1;
+
+    } else {
+        // this is the default - make a best guess - ewmh, areas, workspaces
+        msgout (DEBUG, "vdesktops: making best guess...\n");
+        struct gnome_workspace_info wi;
+        ewmh_get_desktop_info (&wi);
+        c = wi.workspace;
+        nc = wi.workspace_count;
+        nr = 1;
+
+        if (nc == 1) {
+            struct gnome_area_info ai;
+            gnome_get_area_info(&ai);
+            c = ai.harea;
+            r = ai.varea;
+            nc = ai.harea_count;
+            nr = ai.varea_count;
+        
+            if (nc == 1 && nr == 1) {
+                // columns and rows is from workspaces
+                struct gnome_workspace_info wi;
+                gnome_get_workspace_info (&wi);
+                c = wi.workspace;
+                nc = wi.workspace_count;
+                nr = 1;
+                if (nc > 1) cfg->use_workspaces = 1;
+                else msgout (ERROR, "Could not find more then one virtual desktop!\n");
+            } else 
+                cfg->use_viewareas = 1;
+                
+        } else 
+            cfg->use_ewmh = 1; 
+            
     }
 
     msgout (DEBUG, "c=%d, r=%d, nc=%d, nr=%d\n", 
@@ -140,6 +177,7 @@ void VDesktops::get_vdesktop_info (int *column, int *row,
     if (n_rows)    *n_rows = nr;
 }
 
+
 int VDesktops::get_current_desktop (int *column, int *row)
 {
     get_vdesktop_info (column, row, 0, 0);
@@ -175,17 +213,21 @@ void VDesktops::set_vdesktop (int col, int row)
     } else if (cfg->use_ewmh) {
         ewmh_set_current_desktop (col);
 
-    } else {  // default GNOME 1.x
-
+    } else if (cfg->use_viewareas) {
         //msgout(DEBUG, "vdesktops: areas\n");
         gnome_set_current_area (col, row);
 
+    } else {
+        msgout (DEBUG, "vdesktops: set: no type predetermined.\n");
+        ewmh_set_current_desktop (col);
+        //gnome_set_current_area (col, row);
+        
     }
 }
 
 
 
-
+#if 0
 
 //===========================
 // pwm
@@ -281,6 +323,7 @@ int VDesktops::pwm_get_workspace_count (void)
     return harea;  // pwm has varea hardcoded as one atm
 }
 
+#endif // if 0
 
 //===========================
 // gnome - areas
@@ -386,7 +429,7 @@ void VDesktops::gnome_get_workspace_info(struct gnome_workspace_info *info)
     if (Get_Window_Property(display, root_win, workspace_atom, &length, 
                             &type, &size, &val)) 
     {
-        msgout(ERROR, "get property WIN_WORKSPACE failed - setting one\n");
+        msgout(DEBUG, "get property WIN_WORKSPACE failed - setting one\n");
         info->workspace = 0;
     } else {
         info->workspace = (long) * (long *)val;
@@ -396,7 +439,7 @@ void VDesktops::gnome_get_workspace_info(struct gnome_workspace_info *info)
     if (Get_Window_Property(display, root_win, workspace_count_atom,
                             &length, &type, &size, &val)) 
     {
-        msgout(ERROR, "get property WIN_WORKSPACE_COUNT failed - setting one\n");
+        msgout(DEBUG, "get property WIN_WORKSPACE_COUNT failed - setting one\n");
         info->workspace_count = 1;
     } else {
         info->workspace_count = (long) * (long *)val;
@@ -445,7 +488,7 @@ void VDesktops::ewmh_get_desktop_info(struct gnome_workspace_info *info)
     if (Get_Window_Property(display, root_win, desktop_atom, &length, 
                             &type, &size, &val)) 
     {
-        msgout(ERROR, "get property _NET_CURRENT_DESKTOP failed - setting one\n");
+        msgout(DEBUG, "get property _NET_CURRENT_DESKTOP failed - setting one\n");
         info->workspace = 0;
     } else {
         info->workspace = (long) * (long *)val;
@@ -455,7 +498,7 @@ void VDesktops::ewmh_get_desktop_info(struct gnome_workspace_info *info)
     if (Get_Window_Property(display, root_win, desktop_count_atom,
                             &length, &type, &size, &val)) 
     {
-        msgout(ERROR, "get property _NET_NUMBER_OF_DESKTOPS failed - setting one\n");
+        msgout(DEBUG, "get property _NET_NUMBER_OF_DESKTOPS failed - setting one\n");
         info->workspace_count = 1;
     } else {
         info->workspace_count = (long) * (long *)val;
